OC.L10N.register(
    "files",
    {
    "Added to favorites" : "Engadido a favoritos",
    "Removed from favorites" : "Retirado de favoritos",
    "You added {file} to your favorites" : "Engadiu {file} aos seus favoritos",
    "You removed {file} from your favorites" : "Retirou {file} dos seus favoritos",
    "Favorites" : "Favoritos",
    "File changes" : "Cambios do ficheiro",
    "Created by {user}" : "Creado por {user}",
    "Changed by {user}" : "Cambiado por {user}",
    "Deleted by {user}" : "Eliminado por {user}",
    "Restored by {user}" : "Restaurado por {user}",
    "Renamed by {user}" : "Renomeado por {user}",
    "Moved by {user}" : "Movido por {user}",
    "\"remote account\"" : "«conta remota»",
    "You created {file}" : "{file} foi creado por Vde.",
    "You created an encrypted file in {file}" : "Vde. creo un ficheiro cifrado en {file}",
    "{user} created {file}" : "{user} creou {file}",
    "{user} created an encrypted file in {file}" : "{user} creou un ficheiro cifrado en {file}",
    "{file} was created in a public folder" : "{file} foi creado nun cartafol público",
    "You changed {file}" : "{file} foi cambiado por Vde.",
    "You changed an encrypted file in {file}" : "Vde. cambiou un ficheiro cifrado en {file}",
    "{user} changed {file}" : "{file} foi cambiado por {user}",
    "{user} changed an encrypted file in {file}" : "{user} cambiou un ficheiro cifrado en {file}",
    "You deleted {file}" : "{file} foi eliminado por Vde.",
    "You deleted an encrypted file in {file}" : "Vde. eliminou un ficheiro cifrado en {file}",
    "{user} deleted {file}" : "{file} foi eliminado por {user}",
    "{user} deleted an encrypted file in {file}" : "{user} eliminou un ficheiro cifrado en {file}",
    "You restored {file}" : "{file} foi restaurado por Vde.",
    "{user} restored {file}" : "{file} foi restaurado por {user}",
    "You renamed {oldfile} (hidden) to {newfile} (hidden)" : "Vde. renomeou {oldfile} (agochado) como {newfile} (agochado)",
    "You renamed {oldfile} (hidden) to {newfile}" : "Vde. renomeou {oldfile} (agochado) como {newfile}",
    "You renamed {oldfile} to {newfile} (hidden)" : "Vde. renomeou {oldfile} como {newfile} (agochado)",
    "You renamed {oldfile} to {newfile}" : "Vde. renomeou {oldfile} como {newfile}",
    "{user} renamed {oldfile} (hidden) to {newfile} (hidden)" : "{user} renomeou {oldfile} (agochado) como {newfile} (agochado)",
    "{user} renamed {oldfile} (hidden) to {newfile}" : "{user} renomeou {oldfile} (agochado) como {newfile}",
    "{user} renamed {oldfile} to {newfile} (hidden)" : "{user} renomeou {oldfile} como {newfile} (agochado)",
    "{user} renamed {oldfile} to {newfile}" : "{user} renomeou {oldfile} como {newfile}",
    "You moved {oldfile} to {newfile}" : "Vde. moveu {oldfile} para {newfile}",
    "{user} moved {oldfile} to {newfile}" : "{user} moveu {oldfile} para {newfile}",
    "A file has been added to or removed from your <strong>favorites</strong>" : "Engadiuse ou retirouse un ficheiro dos seus <strong>favoritos</strong>",
    "Files" : "Ficheiros",
    "A file or folder has been <strong>changed</strong>" : "<strong>Cambiouse</strong> un ficheiro ou cartafol",
    "A favorite file or folder has been <strong>changed</strong>" : "<strong>Cambiouse</strong> un ficheiro ou cartafol favorito",
    "Failed to authorize" : "Produciuse un fallo ao autorizar",
    "Invalid folder path" : "A ruta ao cartafol non é correcta.",
    "Folder not found" : "Non se atopou o cartafol",
    "The file cannot be found" : "Non é posíbel atopar o ficheiro",
    "The destination path does not exist: %1$s" : "Non existe a ruta de destino: %1$s",
    "You do not have permission to create a file at the specified location" : "Vde. non ten permiso para crear un ficheiro na localización especificada",
    "The file could not be converted." : "Non foi posíbel converter o ficheiro.",
    "Could not get relative path to converted file" : "Non foi posíbel obter a ruta relativa ao ficheiro convertido",
    "Limit must be a positive integer." : "O límite debe ser un número enteiro positivo.",
    "The replacement character may only be a single character." : "O carácter de substitución só poderá ser un carácter único.",
    "Filename sanitization already started." : "Xa foi iniciado o saneamento dos nomes do ficheiro.",
    "No filename sanitization in progress." : "O saneamento dos nomes de ficheiro non está en proceso.",
    "Favorite files" : "Ficheiros favoritos",
    "No favorites" : "Non hai favoritos",
    "More favorites" : "Máis favoritos",
    "Accept" : "Aceptar",
    "Reject" : "Rexeitar",
    "Incoming ownership transfer from {user}" : "Transferencia da propiedade entrante de {user}",
    "Do you want to accept {path}?\n\nNote: The transfer process after accepting may take up to 1 hour." : "Quere aceptar {path}?\n\nNota: Ao proceso de transferencia após aceptar pode levarlle ata 1 hora.",
    "Ownership transfer denied" : "Denegouse a transferencia de propiedade",
    "Your ownership transfer of {path} was denied by {user}." : "{user} denegou a súa transferencia de propiedade de {path}.",
    "Ownership transfer failed" : "Produciuse un fallo na transferencia da propiedade",
    "Your ownership transfer of {path} to {user} failed." : "Produciuse un fallo na súa transferencia da propiedade de {path} cara a {user}.",
    "The ownership transfer of {path} from {user} failed." : "Produciuse un fallo na transferencia da propiedade de {path} cara a {user}.",
    "Ownership transfer done" : "Feita a transferencia da propiedade",
    "Your ownership transfer of {path} to {user} has completed." : "Completouse a súa transferencia da propiedade de {path} cara a {user}.",
    "The ownership transfer of {path} from {user} has completed." : "Completouse a transferencia da propiedade de {path} cara a {user}.",
    "in %s" : "en %s",
    "Transferred from %1$s on %2$s" : "Transferido desde %1$s en %2$s",
    "File Management" : "Xestión de ficheiros",
    "Home" : "Inicio",
    "Target folder does not exist any more" : "O cartafol de destino xa non existe",
    "Reload current directory" : "Recargar o directorio actual",
    "Go to the \"{dir}\" directory" : "Vaia ao directorio «{dir}».",
    "Current directory path" : "Ruta do directorio actual",
    "Your have used your space quota and cannot upload files anymore" : "Vde. usou a súa cota de espazo e xa non pode enviar ningún ficheiro más",
    "You do not have permission to upload or create files here." : "Non ten permiso para enviar ou crear ficheiros aquí.",
    "Drag and drop files here to upload" : "Arrastre e solte os ficheiros aquí para envialos",
    "Favorite" : "Favorito",
    "Back" : "Atrás",
    "Toggle selection for file \"{displayName}\"" : "Conmutar a selección para o ficheiro «{displayName}»",
    "Toggle selection for folder \"{displayName}\"" : "Conmutar a selección para o cartafol «{displayName}»",
    "File is loading" : "Estase a cargar o ficheiro",
    "Folder is loading" : "Estase a cargar o cartafol",
    "Filename" : "Nome de ficheiro",
    "Folder name" : "Nome do cartafol",
    "This node is unavailable" : "Este nodo non está dispoñíbel",
    "Another entry with the same name already exists." : "Xa existe outra entrada co mesmo nome.",
    "Invalid filename." : "Nome de ficheiro incorrecto.",
    "Renamed \"{oldName}\" to \"{newName}\"" : "Cambiouse o nome de «{oldName}» a «{newName}»",
    "Rename file" : "Cambiar o nome do ficheiro",
    "Folder" : "Cartafol",
    "Unknown file type" : "Tipo de ficheiro descoñecido",
    "{ext} image" : "Imaxe {ext}",
    "{ext} video" : "Vídeo {ext}",
    "{ext} audio" : "Son {ext}",
    "{ext} text" : "Texto {ext}",
    "Pending" : "Pendentes",
    "Unknown date" : "Data descoñecida",
    "Clear filter" : "Limpar o filtro",
    "Modified" : "Modificado",
    "Search everywhere" : "Buscar en todos os sitios",
    "Type" : "Escribir",
    "Active filters" : "Filtros activos",
    "Remove filter" : "Retirar o filtro",
    "Appearance" : "Aparencia",
    "Show hidden files" : "Amosar os ficheiros agochados",
    "Show file type column" : "Amosar a columna de tipo de ficheiro",
    "Show file extensions" : "Amosar as extensións de ficheiro",
    "Crop image previews" : "Recortar a vista previa das imaxes",
    "General" : "Xeral",
    "Sort favorites first" : "Ordenar primeiro os favoritos",
    "Sort folders before files" : "Ordenar os cartafoles antes que os ficheiros",
    "Enable folder tree view" : "Activar a vista en árbore de cartafoles",
    "Default view" : "Vista predeterminada",
    "All files" : "Todos os ficheiros",
    "Personal files" : "Ficheiros persoais",
    "Additional settings" : "Axustes adicionais",
    "Actions" : "Accións",
    "File actions" : "Accións de ficheiro",
    "Selection" : "Selección",
    "Select all files" : "Seleccionar todos os ficheiros",
    "Deselect all" : "Deseleccionar todo",
    "Select or deselect" : "Seleccionar ou deseleccionar",
    "Select a range" : "Seleccionar un intervalo",
    "Navigation" : "Navegación",
    "Go to parent folder" : "Ir ao cartafol superior",
    "Go to file above" : "Ir ao ficheiro de arriba",
    "Go to file below" : "Ir ao ficheiro de abaixo",
    "Go left in grid" : "Ir á esquerda na grella",
    "Go right in grid" : "Ir á dereita na grella",
    "View" : "Ver",
    "Toggle grid view" : "Alternar a vista como grade",
    "Open file sidebar" : "Abrir a barra lateral do ficheiro",
    "Show those shortcuts" : "Amosar eses atallos",
    "Warnings" : "Advertencias",
    "Warn before changing a file extension" : "Advertir antes de cambiar unha extensión de ficheiro",
    "Warn before deleting a file" : "Advertir antes de borrar un ficheiro",
    "WebDAV URL" : "URL de WebDAV",
    "Create an app password" : "Crear un contrasinal de aplicación",
    "Required for WebDAV authentication because Two-Factor Authentication is enabled for this account." : "É necesario para a autenticación WebDAV porque a autenticación de dous factores está activada para esta conta.",
    "How to access files using WebDAV" : "Como acceder aos ficheiros empregando WebDAV",
    "Total rows summary" : "Resumo total de filas",
    "Toggle selection for all files and folders" : "Conmutar a selección para todos os ficheiros e cartafoles",
    "Name" : "Nome",
    "File type" : "Tipo do ficheiro",
    "Size" : "Tamaño",
    "{displayName}: failed on some elements" : "Produciuse un fallo nalgúns elementos de {displayName}",
    "{displayName}: done" : "{displayName}: feito",
    "{displayName}: failed" : "{displayName}: produciuse un fallo",
    "(selected)" : "(seleccionado)",
    "List of files and folders." : "Lista de ficheiros e cartafoles",
    "You have used your space quota and cannot upload files anymore." : "Vde. usou a súa cota de espazo e xa non pode enviar ningún ficheiro más",
    "Column headers with buttons are sortable." : "As cabeceiras das columnas con botóns pódense ordenar.",
    "This list is not fully rendered for performance reasons. The files will be rendered as you navigate through the list." : "Esta lista non se representa de xeito completo por mor do rendemento. Os ficheiros represéntanse mentres se despraza pola lista.",
    "File not found" : "Non se atopou o ficheiro",
    "_{count} selected_::_{count} selected_" : ["{count} seleccionado","{count} seleccionados"],
    "Search everywhere …" : "Buscar en todos os sitios…",
    "Search here …" : "Buscar aquí…",
    "Search scope options" : "Opcións do alcance da busca",
    "Search here" : "Buscar aquí",
    "Owner" : "Propietario",
    "{usedQuotaByte} used" : "{usedQuotaByte} usado",
    "{used} of {quota} used" : "Usados {used} de {quota}",
    "{relative}% used" : "{relative}% usado",
    "Could not refresh storage stats" : "Non foi posíbel  actualizar as estatísticas de almacenamento",
    "Your storage is full, files can not be updated or synced anymore!" : "O seu espazo de almacenamento está cheo, xa non se poden actualizar nin sincronizar os ficheiros.",
    "Storage information" : "Información de almacenamento",
    "Storage quota" : "Cota de almacenamento",
    "New folder" : "Novo cartafol",
    "Create new folder" : "Crear un cartafol novo",
    "This name is already in use." : "Este nome xa está a ser usado",
    "Create" : "Crear",
    "Files starting with a dot are hidden by default" : "Os ficheiros que comezan cun punto están agochados de xeito predeterminado",
    "Failed to start filename sanitization." : "Produciuse un fallo ao iniciar o saneamento dos nomes de ficheiro.",
    "Failed to refresh filename sanitization status." : "Produciuse un fallo ao actualizar o estado de saneamento dos nomes de ficheiro.",
    "Filename sanitization in progress." : "O saneamento dos nomes de ficheiro está en proceso.",
    "Currently {processedUsers} of {totalUsers} accounts are already processed." : "Xa foron procesadas {processedUsers} de {totalUsers} contas.",
    "Preparing …" : "Preparando…",
    "Refresh" : "Actualizar",
    "All files have been santized for Windows filename support." : "Todos os ficheiros foron saneados para que sexan compatíbeis cos nomes de ficheiro de Windows.",
    "Some files could not be sanitized, please check your logs." : "Non foi posíbel sanear algúns ficheiros, revise os rexistros.",
    "Sanitization errors" : "Erros de saneamento",
    "Not sanitized filenames" : "Nomes de ficheiro sen sanear",
    "Windows filename support has been enabled." : "Está activada a compatibilidade cos nomes de ficheiro de Windows.",
    "While this blocks users from creating new files with unsupported filenames, existing files are not yet renamed and thus still may break sync on Windows." : "Aínda que isto impide aos usuarios crear novos ficheiros con nomes de ficheiro non compatíbeis, os ficheiros existentes aínda non foron renomeados e, polo tanto, aínda poden rachar a sincronización en Windows.",
    "You can trigger a rename of files with invalid filenames, this will be done in the background and may take some time." : "Pode activar o cambio de nome dos ficheiros con nomes non válidos, isto farase en segundo plano e pode levar algún tempo.",
    "Please note that this may cause high workload on the sync clients." : "Teña en conta que isto pode causar unha alta carga de traballo nos clientes de sincronización.",
    "Limit" : "Límite",
    "This allows to configure how many users should be processed in one background job run." : "Isto permite configurar o número de usuarios que deben ser procesados nunha execución de tarefas en segundo plano.",
    "Sanitize filenames" : "Sanear os nomes dos ficheiros",
    "(starting)" : "(iniciando)",
    "Fill template fields" : "Encher os campos do modelo",
    "Submitting fields …" : "Enviando os campos...",
    "Submit" : "Enviar",
    "Choose a file or folder to transfer" : "Escolla un ficheiro ou cartafol para transferir",
    "Transfer" : "Transferencia",
    "Transfer {path} to {userid}" : "Transferir {path} cara a {userid}",
    "Invalid path selected" : "Seleccionou unha ruta incorrecta.",
    "Unknown error" : "Produciuse un erro descoñecido",
    "Ownership transfer request sent" : "Enviouse solicitude de transferencia da propiedade",
    "Cannot transfer ownership of a file or folder you do not own" : "Non é posíbel transferir a propiedade dun ficheiro ou cartafol do que non es o propietario",
    "Transfer ownership of a file or folder" : "Transferencia da propiedade dun ficheiro ou cartafol",
    "Choose file or folder to transfer" : "Escolla o ficheiro ou cartafol para transferir",
    "Change" : "Cambiar",
    "New owner" : "Novo propietario",
    "Keep {old}" : "Conservar {old}",
    "Keep without extension" : "Conservar  sen extensión",
    "Use {new}" : "Empregar {new}",
    "Remove extension" : "Retirar a extensión",
    "Change file extension" : "Cambiar a extensión do ficheiro",
    "Changing the file extension from \"{old}\" to \"{new}\" may render the file unreadable." : "Cambiar a extensión de ficheiro de «{old}» a «{new}» pode facer que o ficheiro sexa ilexíbel.",
    "Removing the file extension \"{old}\" may render the file unreadable." : "Retirar a extensión de ficheiro «{old}» pode facer que o ficheiro sexa ilexíbel.",
    "Adding the file extension \"{new}\" may render the file unreadable." : "Engadir a extensión de ficheiro «{new}» pode facer que o ficheiro sexa ilexíbel.",
    "Do not show this dialog again." : "Non volver amosar este diálogo",
    "Select file or folder to link to" : "Seleccione o ficheiro ou cartafol ao que ligar",
    "Choose {file}" : "Escoller {file}",
    "Files settings" : "Axustes de Ficheiros",
    "Share" : "Compartir",
    "Shared by link" : "Compartido por ligazón",
    "Shared" : "Compartido",
    "Switch to list view" : "Cambiar á vista de lista",
    "Switch to grid view" : "Cambiar á vista de grade",
    "The file could not be found" : "Non foi posíbel atopar o ficheiro",
    "Upload was cancelled by user" : "O envío foi cancelado polo usuario",
    "Not enough free space" : "Non hai espazo libre abondo",
    "Operation is blocked by access control" : "A operación está a se bloqueda polo control de acceso",
    "Error during upload: {message}" : "Produciuse un erro durante o envío: {message}",
    "Error during upload, status code {status}" : "Produciuse un erro durante o envío, código de estado {status}",
    "Unknown error during upload" : "Produciuse un erro descoñecido durante o envío",
    "Loading current folder" : "Cargando o cartafol actual",
    "Retry" : "Volver tentar",
    "No files in here" : "Aquí non hai ficheiros",
    "Upload some content or sync with your devices!" : "Envíe algún contido ou sincronice cos seus dispositivos!",
    "Go back" : "Volver",
    "Views" : "Vistas",
    "Loading …" : "Cargando…",
    "Your files" : "Os seus ficheiros",
    "Open in files" : "Abrir en ficheiros",
    "File cannot be accessed" : "Non é posíbel acceder ao ficheiro",
    "The file could not be found or you do not have permissions to view it. Ask the sender to share it." : "Non foi posíbel atopar o ficheiro ou non ten permiso para velo. Pídalle ao remitente que o comparta.",
    "No search results for “{query}”" : "Sen resultados de busca para «{query}»",
    "Search for files" : "Buscar ficheiros",
    "Allow to restrict filenames to ensure files can be synced with all clients. By default all filenames valid on POSIX (e.g. Linux or macOS) are allowed." : "Permitir restrinxir os nomes de ficheiros para garantir que os ficheiros se poidan sincronizar con todos os clientes. De xeito predeterminado, permítense todos os nomes de ficheiro válidos en POSIX (p. ex., Linux ou macOS).",
    "After enabling the Windows compatible filenames, existing files cannot be modified anymore but can be renamed to valid new names by their owner." : "Após activar os nomes de ficheiro compatíbeis con Windows, os ficheiros existentes xa non poden ser modificados, mais poden ser renomeados con novos nomes válidos polo seu propietario.",
    "Failed to toggle Windows filename support" : "Poduciuse un fallo ao activar a compatibilidade cos nomes de ficheiro de Windows",
    "Files compatibility" : "Compatibilidade de ficheiros",
    "Enforce Windows compatibility" : "Forzar a compatibilidade con Windows",
    "This will block filenames not valid on Windows systems, like using reserved names or special characters. But this will not enforce compatibility of case sensitivity." : "Isto bloqueará os nomes de ficheiros non válidos en sistemas Windows, coma o uso de nomes reservados ou caracteres especiais. Porén, isto non forzará á compatibilidade da distinción entre maiúsculas e minúsculas.",
    "Blank" : "Baleiro",
    "Unable to create new file from template" : "Non é posíbel crear un novo ficheiro a partir do modelo",
    "Pick a template for {name}" : "Escolla un modelo para {name}",
    "Create a new file with the selected template" : "Crear un novo ficheiro co modelo seleccionado",
    "Creating file" : "Creando o ficheiro",
    "Save as {displayName}" : "Gardar como {displayName}",
    "Save as …" : "Gardar como…",
    "Converting files …" : "Convertendo ficheiros…",
    "Failed to convert files: {message}" : "Produciuse un fallo ao converter os ficheiros: {message}",
    "All files failed to be converted" : "Non foi posíbel converter ningún ficheiro",
    "One file could not be converted: {message}" : "Non foi posíbel converter un ficheiro: {message}",
    "_%n file could not be converted_::_%n files could not be converted_" : ["Non foi posíbel converter %n ficheiro","Non foi posíbel converter %n ficheiros"],
    "_%n file converted_::_%n files converted_" : ["%n ficheiro convertido","%n ficheiros convertidos"],
    "Files converted" : "Ficheiros convertidos",
    "Failed to convert files" : "Produciuse un fallo ao converter os ficheiros",
    "Converting file …" : "Convertendo o ficheiro…",
    "File successfully converted" : "O ficheiro foi convertido correctamente",
    "Failed to convert file: {message}" : "Produciuse un fallo ao converter o ficheiro: {message}",
    "Failed to convert file" : "Produciuse un fallo ao converter o ficheiro",
    "Delete" : "Eliminar",
    "Leave this share" : "Deixar esta compartición",
    "Leave these shares" : "Deixar estas comparticións",
    "Disconnect storage" : "Desconectar o almacenamento",
    "Disconnect storages" : "Desconectar os almacenamentos",
    "Delete permanently" : "Eliminar definitivamente",
    "Delete and unshare" : "Eliminar e deixar de compartir",
    "Delete file" : "Eliminar ficheiro",
    "Delete files" : "Eliminar ficheiros",
    "Delete folder" : "Eliminar o cartafol",
    "Delete folders" : "Eliminar cartafoles",
    "_You are about to permanently delete {count} item_::_You are about to permanently delete {count} items_" : ["Está a piques de eliminar definitivamente {count} elemento","Está a piques de eliminar definitivamente {count} elementos"],
    "_You are about to delete {count} item_::_You are about to delete {count} items_" : ["Está a piques de eliminar {count} elemento","Está a piques de eliminar {count} elementos"],
    "Confirm deletion" : "Confirmar a eliminación",
    "Cancel" : "Cancelar",
    "Download" : "Descargar",
    "The requested file is not available." : "O ficheiro solicitado non está dispoñíbel.",
    "The requested files are not available." : "Os ficheiros solicitados non están dispoñíbeis",
    "Add to favorites" : "Engadir a favoritos",
    "Remove from favorites" : "Retirar de favoritos",
    "Add or remove favorite" : "Engadir ou retirar favoritos",
    "Moving \"{source}\" to \"{destination}\" …" : "Movendo «{source}» a «{destination}»…",
    "Copying \"{source}\" to \"{destination}\" …" : "Copiando «{source}» en «{destination}»…",
    "Destination is not a folder" : "O destino non é un cartafol",
    "This file/folder is already in that directory" : "Este ficheiro/cartafol xa está nese directorio",
    "You cannot move a file/folder onto itself or into a subfolder of itself" : "Non é posíbel mover un ficheiro/cartafol sobre si mesmo ou a un subcartafol de si mesmo",
    "(copy)" : "(copiar)",
    "(copy %n)" : "(copiar %n)",
    "A file or folder with that name already exists in this folder" : "Neste cartafol xa existe un ficheiro ou cartafol con ese nome",
    "The files are locked" : "Os ficheiros están bloqueados",
    "The file does not exist anymore" : "O ficheiro xa non existe",
    "Choose destination" : "Escoller o destino",
    "Copy to {target}" : "Copiar en {target}",
    "Copy" : "Copiar",
    "Move to {target}" : "Mover a {target}",
    "Move" : "Mover",
    "Move or copy operation failed" : "Produciuse un erro na operación de copia ou de movemento",
    "Move or copy" : "Mover ou copiar",
    "Open folder" : "Abrir o cartafol",
    "Open folder {displayName}" : "Abrir o cartafol  {displayName}",
    "Open in Files" : "Abrir en Ficheiros",
    "Open locally" : "Abrir localmente",
    "Failed to redirect to client" : "Produciuse un fallo ao redirixir ao cliente",
    "Open file locally" : "Abrir o ficheiro localmente",
    "The file should now open on your device. If it doesn't, please check that you have the desktop app installed." : "O ficheiro debería abrirse agora no seu dispositivo. Se non é así, comprobe se ten instalada a aplicación de escritorio.",
    "Retry and close" : "Tentar de novo e pechar",
    "Open online" : "Abrir en liña",
    "Rename" : "Cambiar o nome",
    "Details" : "Detalles",
    "Unfavorite" : "Retirar de favoritos",
    "View in folder" : "Ver no cartafol",
    "Today" : "Hoxe",
    "Last 7 days" : "Últimos 7 días",
    "Last 30 days" : "Últimos 30 días",
    "This year ({year})" : "Este ano ({year})",
    "Last year ({year})" : "O ano pasado ({year})",
    "Documents" : "Documentos",
    "Spreadsheets" : "Follas de cálculo",
    "Presentations" : "Presentacións",
    "PDFs" : "PDF",
    "Folders" : "Cartafoles",
    "Audio" : "Son",
    "Images" : "Imaxes",
    "Videos" : "Vídeos",
    "Created new folder \"{name}\"" : "Creouse un novo cartafol «{name}»",
    "Unable to initialize the templates directory" : "Non é posíbel preparar o directorio de modelos",
    "Create templates folder" : "Crear o cartafol de modelos",
    "Templates" : "Modelos",
    "New template folder" : "Novo cartafol de modelos",
    "In folder" : "No cartafol",
    "Search in all files" : "Buscar en todos os ficheiros",
    "Search in folder: {folder}" : "Buscar no cartafol: {folder}",
    "One of the dropped files could not be processed" : "Non foi posíbel procesar un dos ficheiros arrastrados",
    "Your browser does not support the Filesystem API. Directories will not be uploaded" : "O seu navegador non é compatíbel coa API do sistema de ficheiros. Os directorios non van ser enviados",
    "No files to upload" : "Non hai ficheiros que enviar",
    "Unable to create the directory {directory}" : "Non é posíbel crear o directorio {directory}",
    "Some files could not be uploaded" : "Non foi posíbel enviar algúns ficheiros",
    "Files uploaded successfully" : "Ficheiros enviados satisfactoriamente",
    "No files to process" : "Non hai ficheiros para procesar",
    "Some files could not be copied" : "Non foi posíbel copiar algúns ficheiros",
    "Some files could not be moved" : "Non foi posíbel mover algúns ficheiros",
    "Files copied successfully" : "Ficheiros copiados correctamente",
    "Files moved successfully" : "Ficheiros movidos correctamente",
    "Conflicts resolution skipped" : "Omitiuse a resolución dos conflitos",
    "Upload cancelled" : "Envío cancelado",
    "Could not rename \"{oldName}\", it does not exist any more" : "Non foi posíbel cambiarlle o nome a «{oldName}», xa non existe",
    "The name \"{newName}\" is already used in the folder \"{dir}\". Please choose a different name." : "O nome «{newName}» xa se utiliza no cartafol «{dir}». Escolla un nome diferente.",
    "Could not rename \"{oldName}\"" : "Non foi posíbel cambiarlle o nome a «{oldName}»",
    "This operation is forbidden" : "Esta operación está prohibida",
    "This folder is unavailable, please try again later or contact the administration" : "Este cartafol non está dispoñíbel, ténteo de novo máis tarde ou póñase en contacto coa administración",
    "Storage is temporarily not available" : "O almacenamento non está dispoñíbel temporalmente",
    "Unexpected error: {error}" : "Produciuse un erro non agardado: {error}",
    "_%n file_::_%n files_" : ["%n ficheiro","%n ficheiros"],
    "_%n folder_::_%n folders_" : ["%n cartafol","%n cartafoles"],
    "_%n hidden_::_%n hidden_" : ["%n agochado","%n agochados"],
    "Filename must not be empty." : "O nome de ficheiro non debe estar baleiro",
    "\"{char}\" is not allowed inside a filename." : "«{char}» non está permitido nun nome de ficheiro.",
    "\"{segment}\" is a reserved name and not allowed for filenames." : "«{segment}» é un nome reservado e non está permitido para os nomes de ficheiro.",
    "\"{extension}\" is not an allowed filetype." : "«{extension}» non é un tipo de ficheiro permitido.",
    "Filenames must not end with \"{extension}\"." : "Os nomes de ficheiros non deben rematar con «{extension}».",
    "List of favorite files and folders." : "Lista de ficheiros e cartafoles favoritos.",
    "No favorites yet" : "Aínda non hai favoritos",
    "Files and folders you mark as favorite will show up here" : "Os ficheiros e cartafoles que marque como favoritos amosaranse aquí",
    "List of your files and folders." : "Lista dos seus ficheiros e cartafoles",
    "Folder tree" : "Árbore de cartafoles",
    "List of your files and folders that are not shared." : "Lista dos seus ficheiros e cartafoles que non están a seren compartidos.",
    "No personal files found" : "Non se atopou ningún ficheiro persoal",
    "Files that are not shared will show up here." : "Os ficheiros que non se comparten amosaranse aquí.",
    "Recent" : "Recente",
    "List of recently modified files and folders." : "Lista de ficheiros e cartafoles modificados recentemente.",
    "No recently modified files" : "Non hai ficheiros modificados recentemente",
    "Files and folders you recently modified will show up here." : "Os ficheiros e cartafoles que modificou recentemente amosaranse aquí.",
    "Search" : "Buscar",
    "Search results within your files." : "Buscar resultados nos seus ficheiros.",
    "No entries found in this folder" : "Non se atopou ningunha entrada neste cartafol",
    "Select all" : "Seleccionar todo",
    "Upload too large" : "Envío grande de máis",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Os ficheiros que tenta enviar exceden do tamaño máximo permitido neste servidor",
    "%1$s (renamed)" : "%1$s (renomeado)",
    "renamed file" : "ficheiro renomeado",
    "Upload (max. %s)" : "Envío (máx. %s)",
    "After enabling the windows compatible filenames, existing files cannot be modified anymore but can be renamed to valid new names by their owner." : "Após activar os nomes de ficheiro compatíbeis con Windows, os ficheiros existentes xa non poden ser modificados, mais poden ser renomeados con novos nomes válidos polo seu propietario.",
    "It is also possible to migrate files automatically after enabling this setting, please refer to the documentation about the occ command." : "Tamén é posíbel migrar os ficheiros automaticamente após activar esta configuración, consulte a documentación sobre a orde occ.",
    "\"{displayName}\" failed on some elements" : "Produciuse un fallo nalgúns elementos de «{displayName}»",
    "\"{displayName}\" batch action executed successfully" : "A acción por lotes «{displayName}» executouse correctamente",
    "\"{displayName}\" action failed" : "Produciuse un fallo na acción «{displayName}»",
    "Submitting fields …" : "Enviando os campos...",
    "\"{displayName}\" action executed successfully" : "A acción «{displayName}» executouse correctamente",
    "Filter file names …" : "Filtrar os nomes de ficheiro…",
    "Clipboard is not available" : "O portapapeis non está dispoñíbel",
    "WebDAV URL copied to clipboard" : "O URL de WebDAV foi copiado no portapapeis",
    "Enable the grid view" : "Activar a vista de grade",
    "Enable folder tree" : "Activar a árbore de cartafoles",
    "WebDAV" : "WebDAV",
    "Copy to clipboard" : "Copiar no portapapeis.",
    "Use this address to access your Files via WebDAV" : "Empregue este enderezo para acceder ao seu Ficheiros mediante WebDAV",
    "If you have enabled 2FA, you must create and use a new app password by clicking here." : "Se activou 2FA, cree e utilice un novo contrasinal de aplicación premendo aquí.",
    "Prevent warning dialogs from open or reenable them." : "Impedir abrir ou reactivar os diálogos de advertencia",
    "Show a warning dialog when changing a file extension." : "Amosar un diálogo de advertencia ao cambiar unha extensión de ficheiro.",
    "Keyboard shortcuts" : "Atallos de teclado",
    "Speed up your Files experience with these quick shortcuts." : "Acelere a súa experiencia con Ficheiros con estes atallos rápidos.",
    "Open the actions menu for a file" : "Abrir o menú de accións dun ficheiro",
    "Rename a file" : "Cambiar o nome dun ficheiro",
    "Delete a file" : "Eliminar un ficheiro",
    "Favorite or remove a file from favorites" : "Marcar como favorito ou retirar un ficheiro dos favoritos",
    "Manage tags for a file" : "Xestionar etiquetas para un ficheiro",
    "Deselect all files" : "Deseleccionar todos os ficheiros",
    "Select or deselect a file" : "Seleccione ou deseleccione un ficheiro",
    "Select a range of files" : "Seleccionar un intervalo de ficheiros",
    "Navigate to the parent folder" : "Navegar ata o cartafol principal",
    "Navigate to the file above" : "Navegar ata o ficheiro anterior",
    "Navigate to the file below" : "Navegar ata o ficheiro seguinte",
    "Navigate to the file on the left (in grid mode)" : "Navegar ata o ficheiro da esquerda (en modo de grade)",
    "Navigate to the file on the right (in grid mode)" : "Navegar ata o ficheiro da dereita (en modo de grade)",
    "Toggle the grid view" : "Cambiar á vista de grade",
    "Open the sidebar for a file" : "Abrir a barra lateral dun ficheiro",
    "You" : "Vde.",
    "Shared multiple times with different people" : "Compartido varias veces con diferentes persoas",
    "Unable to change the favorite state of the file" : "Non é posíbel cambiar o estado de favorito do ficheiro",
    "Error while loading the file data" : "Produciuse un erro ao cargar os datos do ficheiro",
    "Tags" : "Etiquetas",
    "Save as …" : "Gardar como…",
    "Converting files …" : "Convertendo ficheiros…",
    "Converting file …" : "Convertendo o ficheiro…",
    "Deletion cancelled" : "Foi cancelada a eliminación",
    "Edit locally" : "Editar localmente",
    "Moving \"{source}\" to \"{destination}\" …" : "Movendo «{source}» a «{destination}»…",
    "Copying \"{source}\" to \"{destination}\" …" : "Copiando «{source}» en «{destination}»…",
    "Move cancelled" : "Cancelouse o movemento",
    "Cancelled move or copy of \"{filename}\"." : "Foi cancelado o movemento ou copia de «{filename}»",
    "Cancelled move or copy operation" : "Foi cancelada a operación de movemento ou copia",
    "Open details" : "Abrir detalles",
    "Photos and images" : "Fotos e imaxes",
    "New folder creation cancelled" : "Cancelouse a creación dun novo cartafol",
    "This directory is unavailable, please check the logs or contact the administrator" : "Este directorio non está dispoñíbel, consulte os ficheiros de rexistro ou póñase en contacto coa administración desta instancia.",
    "All folders" : "Todos os cartafoles",
    "Search everywhere …" : "Buscar en todos os sitios…",
    "Search here …" : "Buscar aquí…",
    "Preparing …" : "Preparando…"
},
"nplurals=2; plural=(n != 1);");
